# API Headers

1. link TestLogHeaderLIS.test_05(): Empty API header from LIS data (upright).
2. link TestLogHeaderLIS.test_06(): Empty API header from LIS data (rotated).
3. link TestLogHeaderLIS.test_10(): API header with CONS information from LIS data (upright).
4. link TestLogHeaderLIS.test_11(): API header with CONS information from LIS data (rotated).
5. link TestLogHeaderLAS.test_05(): Empty API header from LAS data (upright).
6. link TestLogHeaderLAS.test_06(): Empty API header from LAS data (rotated).
7. link TestLogHeaderLAS.test_10(): API header with CONS information from LAS data (upright).
8. link TestLogHeaderLAS.test_11(): API header with CONS information from LAS data (rotated).

# Plots from LIS files

1. link TestPlotReadLIS_SingleSinCurve.test_01(): Sinusoidal SP plotted on a number of different scales.
2. link TestPlotReadLIS_SingleSquareCurveLowFreq.test_01(): Square wave with 4' spacing to check wrap interpolation.
3. link TestPlotReadLIS_SingleSquareCurveHighFreq.test_01(): Square wave with 0.5' spacing to check wrap interpolation.
4. link TestPlotReadLIS_SingleSquareCurveSuperHighFreq.test_01(): Square wave with 0.5' spacing to check super high wrap interpolation.
5. link TestPlotReadLIS_HDT.test_01(): 50 feet of HDT on a 1:200 scale.
6. link TestPlotReadLIS_HDT_20.test_01(): 50 feet of HDT on a 1:20 scale.
7. link TestPlotReadLIS_HDT_40.test_01(): 50 feet of HDT on a 1:40 scale.
8. link TestPlotReadLIS_SuperSampled.test_01(): Channels at 4' frame spacing, single, x8, x32 super-sampling.
9. link TestPlotReadLIS_COLO_Named.test_01(): Sinusoidal SP plotted on a number of different named colours.
10. link TestPlotReadLIS_COLO_Numbered.test_01(): Numbered colours 400 (red), 040 (green), 004 (blue).
11. link TestPlotReadLIS_COLO_Numbered_Comp.test_01(): Numbered colours 440 (yellow), 404 (magenta), 044 (cyan).
12. link TestPlotReadLIS_Perf_00.test_01(): Film 1 2000' of 10 curves, linear scale.
13. link TestPlotReadLIS_Perf_00.test_02(): Film 2 2000' of 10 curves, linear and log scale.
14. link LgFormat: "Triple_Combo_00" 2000 of 10 curves, linear and log scale.
15. link LgFormat: "Resistivity_3Track_Logrithmic.xml_00" 2000' of 10 curves, linear and log scale.
16. link LgFormat: "HDT_Example.svg" 25' of example HDT on 1:40 scale with API header.
17. link TestPlotReadLIS_SingleSinCurve.test_01(): Sinusoidal SP plotted on a number of different scales with API header.

# Plots from LAS files

1. link LgFormat: "Triple_Combo" 200 of 15 curves, linear and log scale from LAS file, DOWN log, no header.
2. link LgFormat: "Resistivity_3Track_Logrithmic.xml" 200' of 15 curves, linear and log scale from LAS file, DOWN log, no header.
3. link LgFormat: "Triple_Combo" 200 of 10 curves, linear and log scale from LAS file, DOWN log, with header.
4. link LgFormat: "Resistivity_3Track_Logrithmic.xml" 200' of 15 curves, linear and log scale from LAS file, DOWN log, with header.
5. link LgFormat: "Triple_Combo" 200 of 15 curves, linear and log scale from LAS file, UP log, no header.
6. link LgFormat: "Resistivity_3Track_Logrithmic.xml" 200' of 15 curves, linear and log scale from LAS file, UP log, no header.
7. link LgFormat: "Triple_Combo" 200 of 15 curves, linear and log scale from LAS file, UP log, with header.
8. link LgFormat: "Resistivity_3Track_Logrithmic.xml" 200' of 15 curves, linear and log scale from LAS file, UP log, with header.
9. link LgFormat: "Triple_Combo" 1000 of 15 curves, linear and log scale from LAS file, large down log, with header.
10. link LgFormat: "Resistivity_3Track_Logrithmic.xml" 1000' of 15 curves, linear and log scale from LAS file, large down log, with header.
11. link LgFormat: "Triple_Combo" 100 feet of 5 gamma ray curves.
12. link LgFormat: "Resistivity_3Track_Logrithmic.xml" 100 feet of 5 gamma ray curves.
13. link LgFormat: "Porosity_GR_3Track" 100 feet of Density, porosity and 5 gamma ray curves.